---
name: Bug report
about: Create a report to help us improve
title: Bug
labels: bug
assignees: diantonioandrea
---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
The code to reproduce the behaviour.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Desktop (please complete the following information):**

- OS: [e.g. Windows]
- Version or commit

**Additional context**
Add any other context about the problem here.
